# -*- coding: utf-8 -*-

__author__ = 'Diego Navarro'
__email__ = 'diego@feverup.com'
__version__ = '0.1.3'

try:
    from pysugarcrm import SugarCRM  # noqa
except ImportError:
    # this import is not needed in python 3, not sure it's necessary in python 2
    pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_pysugarcrm
----------------------------------

Tests for `pysugarcrm` module.
"""

import json
import unittest
import responses

from pysugarcrm import SugarCRM


class TestPysugarcrm(unittest.TestCase):

    def setUp(self):
        pass

    @responses.activate
    def test_login(self):
        test_access_token = "dsf3898sdjsdfj388jdsj8"
        responses.add(
            responses.POST,
            'http://testserver.com/rest/v10/oauth2/token',
            body=json.dumps({'access_token': test_access_token}),
            status=200
        )

        api = SugarCRM('http://testserver.com/', "admin", "12345")
        self.assertEqual(api.secret_token, test_access_token)
